@@ -1,15 +1,19 @@
-from prometheus_client import Counter
+from prometheus_client import Counter, Histogram
+
+from django_prometheus.conf import NAMESPACE
 
 connections_total = Counter(
     "django_db_new_connections_total",
     "Counter of created connections by database and by vendor.",
     ["alias", "vendor"],
+    namespace=NAMESPACE,
 )
 
 connection_errors_total = Counter(
     "django_db_new_connection_errors_total",
     "Counter of connection failures by database and by vendor.",
     ["alias", "vendor"],
+    namespace=NAMESPACE,
 )
 
 execute_total = Counter(
@@ -19,6 +23,7 @@ execute_total = Counter(
         " bulk executions."
     ),
     ["alias", "vendor"],
+    namespace=NAMESPACE,
 )
 
 
@@ -26,6 +31,7 @@ execute_many_total = Counter(
     "django_db_execute_many_total",
     ("Counter of executed statements in bulk operations by database and" " by vendor."),
     ["alias", "vendor"],
+    namespace=NAMESPACE,
 )
 
 
@@ -33,4 +39,12 @@ errors_total = Counter(
     "django_db_errors_total",
     ("Counter of execution errors by database, vendor and exception type."),
     ["alias", "vendor", "type"],
+    namespace=NAMESPACE,
+)
+
+query_duration_seconds = Histogram(
+    "django_db_query_duration_seconds",
+    ("Histogram of query duration by database and vendor."),
+    ["alias", "vendor"],
+    namespace=NAMESPACE,
 )
