@@ -1,14 +1,9 @@
-import sys
+from unittest.mock import MagicMock
 
 from django.test import SimpleTestCase
 from django_prometheus.migrations import ExportMigrationsForDatabase
 from django_prometheus.testutils import PrometheusTestCaseMixin
 
-if sys.version_info[:2] >= (3, 0):
-    from unittest.mock import MagicMock
-else:
-    from mock import MagicMock
-
 
 def M(metric_name):
     """Make a full metric name from a short metric name.
@@ -26,12 +21,12 @@ class TestMigrations(PrometheusTestCaseMixin, SimpleTestCase):
         executor = MagicMock()
         executor.migration_plan = MagicMock()
         executor.migration_plan.return_value = set()
-        executor.loader.applied_migrations = set(["a", "b", "c"])
+        executor.loader.applied_migrations = {"a", "b", "c"}
         ExportMigrationsForDatabase("fakedb1", executor)
         self.assertEqual(executor.migration_plan.call_count, 1)
         executor.migration_plan = MagicMock()
-        executor.migration_plan.return_value = set(["a"])
-        executor.loader.applied_migrations = set(["b", "c"])
+        executor.migration_plan.return_value = {"a"}
+        executor.loader.applied_migrations = {"b", "c"}
         ExportMigrationsForDatabase("fakedb2", executor)
 
         self.assertMetricEquals(3, M("applied_total"), connection="fakedb1")
